@@ -47,10 +47,10 @@ translateMousePos :: MousePos -> GLsizei -> GLsizei -> (Double, Double)
 translateMousePos (MousePos x y) winW winH =
     let x' = fromIntegral x
         sW' = fromGLdouble screenResWidth :: Double
-        wW' = (fromIntegral (fromGLsizei winW))
+        wW' = fromIntegral (fromGLsizei winW)
         y' = fromIntegral y
         sH' = fromGLdouble screenResHeight :: Double
-        wH' = (fromIntegral (fromGLsizei winH))
+        wH' = fromIntegral (fromGLsizei winH)
         in (x' * (sW' / wW'),
             sH' - ((sH' - y') * (sH' / wH')))
 
